@@ -4,9 +4,18 @@ import os
 
 
 class ShynaDatabase:
+    """ ShynaDatabase Package
+
+    1) check_connectivity : Check database connectivity
+    2) create_insert_update_or_delete: as per name, no return
+    3) select_from_table : return output as list
+    4) set_date_system: update last run in status_db
+    5) insert_or_update_or_delete_with_status: as per name, return will True or False
+
+    """
     s_time = ShTime.ClassTime()
-    database_user = 'pythoqdx_Shyna'
-    default_database = 'pythoqdx_Shyna'
+    database_user = 'shynax3k_shyna'
+    default_database = ''
     host = os.environ.get('host')
     passwd = os.environ.get('passwd')
     query = ''
@@ -14,6 +23,13 @@ class ShynaDatabase:
     comment = False
 
     def check_connectivity(self):
+        """
+        Check connectivity with database.
+        Before running function, define the default database at class object level.
+        This function will try making connection with it
+        :return: True or False
+
+        """
         status = False
         my_db = mysql.connector.connect(host=self.host,
                                         user=self.database_user,
@@ -75,13 +91,20 @@ class ShynaDatabase:
 
     def set_date_system(self, process_name):
         # print("Device_id", self.device_id)
+        self.default_database = os.environ.get("status_db")
         if self.comment is False:
-            self.query = "UPDATE last_run_check SET task_date = '" + str(self.s_time.now_date) \
-                                + "' , task_time = '" + self.s_time.now_time + "', from_device = '" \
-                                + str(self.device_id) + "' WHERE process_name='" + str(process_name) + "'"
+            self.query = "Insert into last_run_check (task_date, task_time, from_device, process_name) " \
+                         "VALUES('" + str(self.s_time.now_date) + "', '" + str(self.s_time.now_time) + \
+                         "', '" + str(self.device_id) + "','" + str(process_name) + "') " \
+                         "ON DUPLICATE KEY UPDATE task_date='"+ str(self.s_time.now_date) + "', task_time='" \
+                         + self.s_time.now_time + "'"
             self.create_insert_update_or_delete()
         else:
-            self.query = "UPDATE last_run_check SET task_date = '" + str(self.s_time.now_date) + "' , task_time = '" + str(self.s_time.now_time) + "', from_device = '" + str(self.device_id) + "', comment='" + str(self.comment) + "' WHERE process_name='" + str(process_name) + "'"
+            self.query = "Insert into last_run_check (task_date,task_time,from_device,comment,process_name)" \
+                         "VALUES('" + str(self.s_time.now_date) + "', '" + str(self.s_time.now_time) + \
+                         "', '" + str(self.device_id) + "','"+ str(self.comment) + "','" \
+                         + str(process_name) + "') ON DUPLICATE KEY UPDATE task_date='" \
+                         + str(self.s_time.now_date) + "', task_time='" + str(self.s_time.now_time) + "'"
             self.create_insert_update_or_delete()
 
     def insert_or_update_or_delete_with_status(self):
@@ -102,3 +125,4 @@ class ShynaDatabase:
         finally:
             my_db.close()
             return insert_status
+
