@@ -138,13 +138,11 @@ class ShynaIs:
             if "Empty" in self.result:
                 self.is_this = False
             else:
-                for face_time in self.result:
-                    time_diff = (self.s_time.string_to_time_with_date(self.s_time.now_time) - self.s_time.string_to_time_with_date(face_time[0])).total_seconds()
-                    face_time_list.append(time_diff)
-                face_time_list = sorted(face_time_list)
-                for item in face_time_list:
-                    print(item)
-                    if int(item) < 60:
+                for i in range(len(self.result)-1):
+                    # print(self.result[i][0])
+                    time_diff = (self.s_time.string_to_time_with_date(str(self.s_time.now_time)) - self.s_time.string_to_time_with_date(str(self.result[i][0]))).total_seconds()
+                    # print(time_diff)
+                    if int(time_diff) < 60:
                         response.append(True)
                     else:
                         response.append(False)
@@ -497,13 +495,13 @@ class ShynaIs:
             else:
                 for _ in result:
                     for item in _:
-                        if 0.000 < float(item) <= 0.009:
+                        if 0.000 < float(item) <= 0.09:
                             still = still + 1
                             # print("still",item, still)
-                        elif 0.009 < float(item) <= 0.19:
+                        elif 0.09 < float(item) <= 0.9:
                             walking = walking + 1
                             # print("walking",item, walking)
-                        elif 0.19 < float(item):
+                        elif 0.9 < float(item):
                             driving = driving + 1
                             # print("driving",item, driving)
                         else:
@@ -548,8 +546,8 @@ class ShynaIs:
             if str(self.result[0]).lower().__contains__('empty'):
                 self.is_this = False
             else:
-                for i in range(len(self.result)):
-                    print(self.result[i][0])
+                for i in range(len(self.result)-1):
+                    # print(self.result[i][0])
                     time_diff = (self.s_time.string_to_time_with_date(time_string=str(self.result[i][0])) - self.s_time.string_to_time_with_date(time_string=str(self.result[i+1][0]))).total_seconds()
                     print(time_diff)
                     if 60 < int(time_diff) < 100:
@@ -562,4 +560,3 @@ class ShynaIs:
             print(e)
         finally:
             return self.is_this
-
